..
    Copyright (C) 2020 Technische Universität Graz.

    invenio-pure is free software; you can redistribute it and/or
    modify it under the terms of the MIT License; see LICENSE file for more
    details.


Usage
=====

.. automodule:: invenio_pure
